@@ -19,12 +19,12 @@ class BrandingMiddleware(object):
         for key, value in getattr(settings, 'BRANDING', {}).iteritems():
             response[key] = value
 
-        platform = getattr(settings, "PLATFORM")
-        server = getattr(settings, "X_SERVER")
-        programming = getattr(settings, "X_PROGRAMMING")
-        site_name = getattr(settings, "SITE_NAME")
-        version = getattr(settings, 'VERSION')
-        revision = getattr(settings, 'REVISION')
+        platform = getattr(settings, "PLATFORM", None)
+        server = getattr(settings, "X_SERVER", None)
+        programming = getattr(settings, "X_PROGRAMMING", None)
+        site_name = getattr(settings, "SITE_NAME", None)
+        version = getattr(settings, 'VERSION', None)
+        revision = getattr(settings, 'REVISION', None)
 
         if programming:
             response['X-Programming'] = programming
